import { ref } from 'vue';
import { store } from '@/store';
import { useAsRouter } from './useAsRouter'



interface CommonInterface {
	model ?: CommonType.ModelType,
	page ?: CommonType.PageType
	search ?: CommonType.SearchType
	table ?: CommonType.TableType
	delParam ?: CommonType.DeleteType,

}

export const useCommon = () => {
	const { routerTo, routerCur, routerArrayCur } = useAsRouter();
	let commomParams  = ref<CommonInterface>({
		model: {
			title: '',
			okText: '提交',
			resetText: '重置',
			cancelText: '取消',
		},
		
		page: {
			current: 1,
			pageSize: 1,
			total: 10,
			pageSizeOptions: ['10', '20', '30', '40'],
			hideOnSinglePage: false,
			showSizeChanger: true
		},
		
		search: {
			page : 1,
			pagesize : 10,
			sort : 'id', 
			sortby : 'asc', 
			keyword : ''
		},
		
		table: {
			data : [],
			columns : [],
		},

		delParam :{
			id: 0
		},
		
	

		// // MENU
		// openSubMenu: [],
		// menuList: [],
		
	})

	let openAddModel = ref<Boolean>(store.state.openModel);
	let openOtherModel_1 = ref<Boolean>(store.state.openOtherModel_1);

	// 点击菜单获取路由
	const onMenu = (path) => {
		
		routerTo(path);
	};

	// Modal
	const hideModal = () => {
		store.commit('getOpenModel', {
			openAddModel: false
		})
	}

	// 打开添加/编辑对话框
	const showModal = () => {
		store.commit('getOpenModel', {
			openAddModel: true
		})
	};

	const showOtherModal1 = () => {
		store.commit('getOpenMoreModel', {
			openOtherModel_1: true
		})
	};

	const hideOtherModal1 = () => {
		store.commit('getOpenMoreModel', {
			openOtherModel_1: false
		})
	}


	


	return {
		store,
		commomParams,
		openAddModel,
		onMenu,
		hideModal,
		showModal,
		openOtherModel_1,
		showOtherModal1,
		hideOtherModal1,
	}
}